==> jdk-11.0.11_windows-x64_bin.zip: java.xml.crypto/com/sun/org/apache/xml/internal/security/keys/keyresolver/KeyResolverException.java <==
/*
 * Copyright (c) 2007, 2021, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.sun.org.apache.xml.internal.security.keys.keyresolver;

import com.sun.org.apache.xml.internal.security.exceptions.XMLSecurityException;

public class KeyResolverException extends XMLSecurityException {

    /**
     *
     */
    private static final long serialVersionUID = 1L;

    /**
     * Constructor KeyResolverException
     *
     */
    public KeyResolverException() {
        super();
    }

    public KeyResolverException(Exception ex) {
        super(ex);
    }

    /**
     * Constructor KeyResolverException
     *
     * @param msgID
     */
    public KeyResolverException(String msgID) {
        super(msgID);
    }

    /**
     * Constructor KeyResolverException
     *
     * @param msgID
     * @param exArgs
     */
    public KeyResolverException(String msgID, Object exArgs[]) {
        super(msgID, exArgs);
    }

    /**
     * Constructor KeyResolverException
     *
     * @param originalException
     * @param msgID
     */
    public KeyResolverException(Exception originalException, String msgID) {
        super(originalException, msgID);
    }

    @Deprecated
    public KeyResolverException(String msgID, Exception originalException) {
        this(originalException, msgID);
    }

    /**
     * Constructor KeyResolverException
     *
     * @param originalException
     * @param msgID
     * @param exArgs
     */
    public KeyResolverException(Exception originalException, String msgID, Object exArgs[]) {
        super(originalException, msgID, exArgs);
    }

    @Deprecated
    public KeyResolverException(String msgID, Object[] exArgs, Exception originalException) {
        this(originalException, msgID, exArgs);
    }
}

==> jdk-21.0.6_windows-x64_bin.zip: java.xml.crypto/com/sun/org/apache/xml/internal/security/keys/keyresolver/KeyResolverException.java <==
/*
 * Copyright (c) 2007, 2024, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.sun.org.apache.xml.internal.security.keys.keyresolver;

import com.sun.org.apache.xml.internal.security.exceptions.XMLSecurityException;

public class KeyResolverException extends XMLSecurityException {

    /**
     *
     */
    private static final long serialVersionUID = 1L;

    /**
     * Constructor KeyResolverException
     *
     */
    public KeyResolverException() {
        super();
    }

    public KeyResolverException(Exception ex) {
        super(ex);
    }

    /**
     * Constructor KeyResolverException
     *
     * @param msgID
     */
    public KeyResolverException(String msgID) {
        super(msgID);
    }

    /**
     * Constructor KeyResolverException
     *
     * @param msgID
     * @param exArgs
     */
    public KeyResolverException(String msgID, Object[] exArgs) {
        super(msgID, exArgs);
    }

    /**
     * Constructor KeyResolverException
     *
     * @param originalException
     * @param msgID
     */
    public KeyResolverException(Exception originalException, String msgID) {
        super(originalException, msgID);
    }

    @Deprecated
    public KeyResolverException(String msgID, Exception originalException) {
        this(originalException, msgID);
    }

    /**
     * Constructor KeyResolverException
     *
     * @param originalException
     * @param msgID
     * @param exArgs
     */
    public KeyResolverException(Exception originalException, String msgID, Object[] exArgs) {
        super(originalException, msgID, exArgs);
    }

    @Deprecated
    public KeyResolverException(String msgID, Object[] exArgs, Exception originalException) {
        this(originalException, msgID, exArgs);
    }
}
